==> spellathon-5.47.tar.gz: spellathon-5.47/src/gui/settingspersist.cc <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#include <QDir>

#include "settingspersist.h"
#include "../logic/defines.h"

SettingsPersist::SettingsPersist()
{
	settings = new QSettings("Ephemera", "Spellathon");
}

bool
SettingsPersist::load()
{
	dictPrecomp		= settings->value("dict/precomp", PRECOMP).toBool();
	QDir	dp;
	dictPath		= settings->value("dict/path", 
								dp.absoluteFilePath(DICTPATH)).toString();	
	pluralSieve		= settings->value("plural/sieve", PLURAL_SIEVE).toBool();
	showTime		= settings->value("time/show", true).toBool();
	showScore		= settings->value("score/show", true).toBool();
	minSol			= settings->value("solutions/min", MIN_SOL).toInt();
	maxSol			= settings->value("solutions/max", MAX_SOL).toInt();
	mainwindowSize	= settings->value("mainwidget/size", 
									  QSize(350, 500)).toSize();
	mainwindowPos	= settings->value("mainwidget/pos", 
									  QPoint(200, 50)).toPoint();
#ifdef WIN32
	monoFont		= settings->value("font/mono", 
									  QFont("Courier New", 10)).value<QFont>();
#else
	monoFont		= settings->value("font/mono", 
									  QFont("Monospace", 10)).value<QFont>();
#endif /* WIN32 */

	return (settings->status() == QSettings::NoError);
}

bool
SettingsPersist::save()
{
		settings->setValue("dict/precomp", dictPrecomp);
		settings->setValue("mainwidget/size", mainwindowSize);
		settings->setValue("mainwidget/pos", mainwindowPos);
		settings->setValue("dict/path", dictPath);
		settings->setValue("font/mono", monoFont);
		settings->setValue("score/show", showScore);
		settings->setValue("time/show", showTime);
		settings->setValue("plural/sieve", pluralSieve);
		settings->setValue("solutions/min", minSol);
		settings->setValue("solutions/max", maxSol);
		settings->sync();

		return (settings->status() == QSettings::NoError);
}

==> spellathon-5.59.tar.gz: spellathon-5.59/src/gui/settingspersist.cc <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#include <QDir>

#include "settingspersist.h"
#include "../logic/defines.h"

SettingsPersist::SettingsPersist()
{
	settings = new QSettings("Ephemera", "Spellathon");
}

bool
SettingsPersist::load()
{
	dictPrecomp		= settings->value("dict/precomp", PRECOMP).toBool();
	QDir	dp;
	dictPath		= settings->value("dict/path", 
								dp.absoluteFilePath(DICTPATH)).toString();	
	pluralSieve		= settings->value("plural/sieve", PLURAL_SIEVE).toBool();
	showTime		= settings->value("time/show", true).toBool();
	showScore		= settings->value("score/show", true).toBool();
	minSol			= settings->value("solutions/min", MIN_SOL).toInt();
	maxSol			= settings->value("solutions/max", MAX_SOL).toInt();
	mainwindowSize	= settings->value("mainwindow/size", 
									  QSize(325, 480)).toSize();
	mainwindowPos	= settings->value("mainwindow/pos", 
									  QPoint(200, 50)).toPoint();
#ifdef WIN32
	monoFont		= settings->value("font/mono", 
									  QFont("Courier New", 10)).value<QFont>();
#else
	monoFont		= settings->value("font/mono", 
									  QFont("Monospace", 10)).value<QFont>();
#endif /* WIN32 */

	return (settings->status() == QSettings::NoError);
}

bool
SettingsPersist::save()
{
		settings->setValue("mainwindow/size", mainwindowSize);
		settings->setValue("mainwindow/pos", mainwindowPos);
		settings->setValue("dict/path", dictPath);
		settings->setValue("dict/precomp", dictPrecomp);
		settings->setValue("font/mono", monoFont);
		settings->setValue("score/show", showScore);
		settings->setValue("time/show", showTime);
		settings->setValue("plural/sieve", pluralSieve);
		settings->setValue("solutions/min", minSol);
		settings->setValue("solutions/max", maxSol);
		settings->sync();

		return (settings->status() == QSettings::NoError);
}
